# Generated by roxygen2: do not edit by hand

S3method(mergeRows,data.frame)
S3method(normalityTest,default)
S3method(normalityTest,formula)
S3method(plotBoot,boot)
S3method(print,DeltaMethod)
S3method(print,numSummary)
S3method(print,partial.cor)
S3method(print,rcorr.adjust)
S3method(print,reliability)
S3method(summarySandwich,lm)
export(Barplot)
export(CV)
export(DeltaMethod)
export(Dotplot)
export(Hist)
export(KMeans)
export(assignCluster)
export(bin.var)
export(binVariable)
export(binnedCounts)
export(colPercents)
export(cv)
export(dgumbel)
export(discreteCounts)
export(discretePlot)
export(excel_sheets)
export(indexplot)
export(lineplot)
export(mergeRows)
export(normalityTest)
export(numSummary)
export(partial.cor)
export(pgumbel)
export(piechart)
export(plotBoot)
export(plotDistr)
export(plotMeans)
export(qgumbel)
export(rcorr.adjust)
export(readSAS)
export(readSPSS)
export(readStata)
export(readXL)
export(reliability)
export(repeatedMeasuresPlot)
export(reshapeL2W)
export(reshapeW2L)
export(rgumbel)
export(rowPercents)
export(stepwise)
export(summarySandwich)
export(totPercents)
importFrom(Hmisc,rcorr)
importFrom(MASS,stepAIC)
importFrom(abind,abind)
importFrom(car,Tapply)
importFrom(car,deltaMethod)
importFrom(car,hccm)
importFrom(car,linearHypothesis)
importFrom(car,showLabels)
importFrom(colorspace,rainbow_hcl)
importFrom(e1071,kurtosis)
importFrom(e1071,skewness)
importFrom(foreign,read.spss)
importFrom(grDevices,n2mfrow)
importFrom(grDevices,palette)
importFrom(graphics,abline)
importFrom(graphics,arrows)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,box)
importFrom(graphics,hist)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,matplot)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,pie)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,strheight)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(haven,read_sas)
importFrom(haven,read_spss)
importFrom(lattice,strip.default)
importFrom(lattice,xyplot)
importFrom(nortest,ad.test)
importFrom(nortest,cvm.test)
importFrom(nortest,lillie.test)
importFrom(nortest,pearson.test)
importFrom(nortest,sf.test)
importFrom(readxl,excel_sheets)
importFrom(readxl,read_excel)
importFrom(sandwich,vcovHAC)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,dist)
importFrom(stats,formula)
importFrom(stats,ftable)
importFrom(stats,kmeans)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,pf)
importFrom(stats,pt)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,reshape)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,shapiro.test)
importFrom(stats,update)
