% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bin.var.R
\name{bin.var}
\alias{bin.var}
\title{Bin a Numeric Variable}
\usage{
bin.var(...)
}
\arguments{
\item{...}{arguments to be passed to \code{binVariable}.}
}
\description{
Bin a Numeric Variable
}
\details{
\code{bin.var} is a synomym for \code{binVariable}, retained for backwards compatibility.
}
\keyword{internal}
