% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcmdrMisc-package.R
\name{RcmdrMisc-package}
\alias{RcmdrMisc-package}
\title{R Commander Miscellaneous Functions}
\description{
R Commander Miscellaneous Functions
}
\details{
\tabular{ll}{
Package: \tab RcmdrMisc\cr
Version: \tab 2.10.2\cr
Date: \tab 2026-06-15\cr
License: \tab GPL (>=3)\cr
}

Various statistical, graphics, and data-management functions used by the Rcmdr package in the R Commander GUI for R.
}
\seealso{
\url{https://www.r-project.org}, \url{https://github.com/RCmdr-Project/rcmdrmisc}
}
\author{
John Fox

Mantainer: Manuel Munoz-Marquez <manuel.munoz@uca.es>
}
