% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cv.R
\name{cv}
\alias{cv}
\alias{CV}
\title{Coefficient of variation}
\usage{
cv(x, na.rm = TRUE, ...)

CV(x, na.rm = TRUE)
}
\arguments{
\item{x}{data a numeric vector, matrix, or data frame.}

\item{na.rm}{if \code{TRUE} (the default) remove \code{NA}s before computing the coefficient of variation.}

\item{...}{ignored}
}
\value{
\code{cv} returns the coefficient(s) of variation.
}
\description{
Coefficient of variation
}
\details{
\code{numSummary} creates neatly formatted tables of means, standard deviations, coefficients of variation, skewness, kurtosis, and quantiles of numeric variables. \code{CV} computes the coefficient of variation.
}
\examples{
data(Prestige)
print(cv(Prestige[,c("income", "education")]))

}
\author{
John Fox
}
\keyword{internal}
\keyword{misc}
